SectionHeader

Struct SectionHeader 

pub struct SectionHeader {
    pub compression_algo: u8,
    pub format: Format,
    pub more_sections: bool,
    pub num_operations: u32,
    pub num_add_bytes: u32,
    pub output_size: u32,
}
Header struct for a section

Fields

compression_algo: u8

Should be a value between 0-7 per the spec

format: Formatmore_sections: bool

true if there are more sections to decode after this one. false if this is the last section default: false

num_operations: u32

Total number of operations in the section

num_add_bytes: u32

Total Add bytes at the end of the section (not needed for interleaved format)

output_size: u32

Total output size generated from the operations in this section Maximum value should not exceed (1<<24) - 1

Implementations

Source

impl SectionHeader

pub fn new(num_operations: u32, num_add_bytes: u32, output_size: u32) -> Self

Create a new SectionHeader with the given parameters

  • num_operations: Total number of operations in the section
  • num_add_bytes: Total Add bytes at the end of the section (not needed for interleaved format)
  • output_size: Total output size generated from the operations in this section
pub fn set_compression_algo(self, compression_algo: u8) -> Self

Set the compression algorithm to use for this section

  • compression_algo: Should be a value between 0-7 per the spec
pub fn set_format(self, format: Format) -> Self

pub fn set_more_sections(self, more_sections: bool) -> Self

Indicate if this section is not the last section

pub fn is_compressed(&self) -> bool

pub fn is_interleaved(&self) -> bool