pub trait AddOp {
// Required method
fn bytes(&self) -> &[u8] ⓘ;
}Expand description
Trait for the Add Operation Depending on the usage, we may want to store the Add bytes in different ways This trait allows for different implementations of the Add Operation within an Op
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".